|
Neko 1.99.7
A portable framework for high-order spectral element flow simulations
|
#include "elem_block.h"

Go to the source code of this file.
Functions | |
| template<typename T , const int LX, const int CHUNKS> | |
| __global__ void | convect_scalar_kernel_1d (T *__restrict__ du, const T *__restrict__ u, const T *__restrict__ cr, const T *__restrict__ cs, const T *__restrict__ ct, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz) |
| template<typename T , const int LX, const int EB> | |
| __global__ void | __launch_bounds__ ((LX *LX *EB)) convect_scalar_kernel_kstep(T *__restrict__ du |
| if (eb==0) | |
| for (int k=0;k< LX;++k) | |
| __syncthreads () | |
| __global__ void __launch_bounds__ | ( | (LX *LX *EB) | ) |
| __syncthreads | ( | ) |

| __global__ void convect_scalar_kernel_1d | ( | T *__restrict__ | du, |
| const T *__restrict__ | u, | ||
| const T *__restrict__ | cr, | ||
| const T *__restrict__ | cs, | ||
| const T *__restrict__ | ct, | ||
| const T *__restrict__ | dx, | ||
| const T *__restrict__ | dy, | ||
| const T *__restrict__ | dz | ||
| ) |
Device kernel for convect_scalar
Definition at line 44 of file convect_scalar_kernel.h.

| for | ( | ) |
| if | ( | eb | = = 0 | ) |
Definition at line 148 of file convect_scalar_kernel.h.
Definition at line 140 of file convect_scalar_kernel.h.
Definition at line 114 of file convect_scalar_kernel.h.
Definition at line 115 of file convect_scalar_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ ct |
Definition at line 116 of file convect_scalar_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dx |
Definition at line 117 of file convect_scalar_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dy |
Definition at line 118 of file convect_scalar_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dz |
Definition at line 119 of file convect_scalar_kernel.h.
| const int e_blk = blockIdx.x * EB + eb |
Definition at line 136 of file convect_scalar_kernel.h.
Definition at line 135 of file convect_scalar_kernel.h.
| const int i = threadIdx.x |
Definition at line 144 of file convect_scalar_kernel.h.
Definition at line 143 of file convect_scalar_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const int nelv |
Definition at line 120 of file convect_scalar_kernel.h.
Definition at line 155 of file convect_scalar_kernel.h.
Definition at line 156 of file convect_scalar_kernel.h.
Definition at line 157 of file convect_scalar_kernel.h.
Definition at line 154 of file convect_scalar_kernel.h.
| __shared__ T shdx[LX *LX] |
Definition at line 124 of file convect_scalar_kernel.h.
| __shared__ T shdy[LX *LX] |
Definition at line 125 of file convect_scalar_kernel.h.
| __shared__ T shdz[LX *LX] |
Definition at line 126 of file convect_scalar_kernel.h.
Definition at line 113 of file convect_scalar_kernel.h.